@@ -33,7 +33,7 @@
 #include <libcinnamon-desktop/gnome-rr-config.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <libcinnamon-desktop/cdesktop-enums.h>
 
 #include "cc-rr-labeler.h"
@@ -163,13 +163,8 @@ cc_display_panel_finalize (GObject *object)
   g_object_unref (self->priv->builder);
 
   shell = cc_panel_get_shell (CC_PANEL (self));
-  if (shell != NULL)
+  if (shell == NULL)
     {
-      toplevel = cc_shell_get_toplevel (shell);
-      if (toplevel != NULL)
-        g_signal_handler_disconnect (G_OBJECT (toplevel),
-                                     self->priv->focus_id);
-    } else {
         g_signal_handler_disconnect (GTK_WIDGET (self), self->priv->focus_id);
         g_signal_handler_disconnect (GTK_WIDGET (self), self->priv->focus_id_hide);
     }
@@ -264,10 +259,8 @@ on_screen_changed (GnomeRRScreen *scr,
 
   self->priv->labeler = cc_rr_labeler_new (self->priv->current_configuration);
 
-  if (cc_panel_get_shell (CC_PANEL (self)) == NULL)
-    cc_rr_labeler_hide (self->priv->labeler);
-  else
-    cc_rr_labeler_show (self->priv->labeler);
+  cc_rr_labeler_hide (self->priv->labeler);
+  cc_rr_labeler_show (self->priv->labeler);
 
   select_current_output_from_dialog_position (self);
 
@@ -2183,7 +2176,7 @@ begin_version2_apply_configuration (CcDisplayPanel *self, GdkWindow *parent_wind
   self->priv->proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
                                                      G_DBUS_PROXY_FLAGS_NONE,
                                                      NULL,
-                                                     "org.cinnamon.SettingsDaemon",
+                                                     "org.cinnamon.SettingsDaemon.XRANDR_2",
                                                      "/org/cinnamon/SettingsDaemon/XRANDR",
                                                      "org.cinnamon.SettingsDaemon.XRANDR_2",
                                                      NULL,
@@ -2333,6 +2326,9 @@ on_detect_displays (GtkWidget *widget, gpointer data)
       g_error_free (error);
     }
   }
+
+  cc_rr_labeler_hide (self->priv->labeler);
+  cc_rr_labeler_show (self->priv->labeler);
 }
 
 static GnomeRROutputInfo *
@@ -2430,19 +2426,6 @@ get_output_for_window (GnomeRRConfig *configuration, GdkWindow *window)
 			       win_rect.y + win_rect.height / 2);
 }
 
-static void
-dialog_toplevel_focus_changed (GtkWindow      *window,
-			       GParamSpec     *pspec,
-			       CcDisplayPanel *self)
-{
-  if (self->priv->labeler == NULL)
-    return;
-  if (gtk_window_has_toplevel_focus (window))
-    cc_rr_labeler_show (self->priv->labeler);
-  else
-    cc_rr_labeler_hide (self->priv->labeler);
-}
-
 static void
 widget_visible_changed (GtkWidget *widget,
                         gpointer user_data)
@@ -2524,7 +2507,6 @@ cc_display_panel_constructor (GType                  gtype,
 
   error = NULL;
   self->priv->builder = builder = gtk_builder_new ();
-  gtk_builder_set_translation_domain (self->priv->builder, GETTEXT_PACKAGE);
   if (!gtk_builder_add_objects_from_file (builder, UIDIR "/display-capplet.ui", objects, &error))
     {
       g_warning ("Could not parse UI definition: %s", error->message);
@@ -2545,11 +2527,7 @@ cc_display_panel_constructor (GType                  gtype,
 
   shell = cc_panel_get_shell (CC_PANEL (self));
 
-  if (shell != NULL) {
-    toplevel = cc_shell_get_toplevel (shell);
-    self->priv->focus_id = g_signal_connect (toplevel, "notify::has-toplevel-focus",
-                                           G_CALLBACK (dialog_toplevel_focus_changed), self);
-  } else {
+  if (shell == NULL) {
     self->priv->focus_id = g_signal_connect (GTK_WIDGET (self), "show",
                                              G_CALLBACK (widget_visible_changed), NULL);
     self->priv->focus_id_hide = g_signal_connect (GTK_WIDGET (self), "hide",
@@ -2624,6 +2602,7 @@ cc_display_panel_constructor (GType                  gtype,
 void
 cc_display_panel_register (GIOModule *module)
 {
+  textdomain (GETTEXT_PACKAGE);
   bindtextdomain (GETTEXT_PACKAGE, "/usr/share/locale");
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   cc_display_panel_register_type (G_TYPE_MODULE (module));
